==> dl.php?src=linea21_1_1.zip: linea21/languages/fr/lang_scale.utf-8.php <==
<?php


// //////////////////////////////////////////////////
// Linea 21 - PHP language FR
// configuration des langues des modules
// create : 19/06/07
// last_modify : 20/06/07
// creative commons 2007 
//http://creativecommons.org/licenses/by-nc-sa/2.0/fr/legalcode
// //////////////////////////////////////////////////
/**
* lang_FR.php
* 
* @package linea21
* @author anthony 
* @copyright Copyright (c) green-box 2003
* @version 1.0
* @access public 
*/



/*	nommage des modules
*  	*/
$lang['scale']['name']="échelle";
$lang['scale']['confirm_add'] = "Ajout de l'échelle réalisé avec succès\n";
$lang['scale']['confirm_mod'] = "Modification de l'échelle réalisée avec succès\n";
$lang['scale']['confirm_sup'] ="Suppression de l'échelle réalisée avec succès\n";


/*	nommage rubrique module
*  	*/
$lang['scale']['add']= "Ajout d'une ".$lang['scale']['name'];
$lang['scale']['mod']= "Modification d'une ".$lang['scale']['name'];
$lang['scale']['sup']= "Suppression d'une ".$lang['scale']['name'];
$lang['scale']['det']= "Détails de l'".$lang['scale']['name'];
$lang['scale']['list']= "Consultation des ".$lang['scale']['name']."s";


/*	nommage rubrique add / mod /det
*  	*/
$lang['scale']['add_title']="Saisie des informations de la nouvelle ".$lang['scale']['name'];



/*	nommage rubrique sup
*  	*/
$lang['scale']['sup_massd']= "Supprimer toutes les échelles filles attachées ?";
$lang['scale']['sup_massm']= "Attacher toutes ses échelles filles à une autre échelle ?"; 
$lang['scale']['sup_transfert']= "Echelle de transfert"; 
/*	nommage élément rubrique
*  	*/
$lang['scale']['denomination']="Dénomination de l'".$lang['scale']['name'];
$lang['scale']['surface']="Surface de la zone en";
$lang['scale']['population']="Nombre d'habitants";
$lang['scale']['root']="Echelle parente";
$lang['scale']['comment']="Commentaire lié à cette ".$lang['scale']['name'];


/*	nommage quickbox
*  	*/
$lang['scale']['qb_titleadd']=" derniers ajouts effectués";
$lang['scale']['qb_titlemod']=" dernières modifications effectuées";
$lang['scale']['qb_titlesup']=" dernières suppressions effectuées";


/*	divers
*  	*/
$lang['scale']['select_choice']="~~ Faites votre choix dans la liste ci dessous ~~";


/*	messages
*  	*/
$lang['scale']['object_notdenomination']="Vous devez impérativement entrer une dénomination d'échelle.";
$lang['scale']['object_notnumsurface']="La superficie saisie doit être de type numérique.";
$lang['scale']['object_notnuminhabitants']="La population saisie doit être de type numérique (entier).";
$lang['scale']['object_notroot']="Vous devez impérativement déterminer une échelle <em>parente</em> à la nouvelle échelle.";
$lang['scale']['sup_nomethod']="Vous devez impérativement choisir une méthode de suppression!";
$lang['scale']['sup_noscale']="Vous devez impérativement choisir une échelle de transfert!";
$lang['scale']['sup_scale_info1']="Attention, le transfert de cette échelle induit le transfert des échelles filles attachées, des actualités, publications et indicateurs liés à cette échelle!";
$lang['scale']['sup_scale_info2']="Attention, la suppression de cette échelle induit celle des échelles filles attachées, des actualités, publications et indicateurs liés à cette échelle!";


/*	rubrique d'aide
*  	*/
$lang['scale']['help_add1']="Pour ajouter une échelle, vous devez entrer chacun de ses paramètres dans le formulaire ci-dessus";
$lang['scale']['help_add2']="Vous devez impérativement ajouter une échelle parente à la nouvelle échelle";
$lang['scale']['help_add3']="Après avoir validé le formulaire d'ajout, vérifiez les informations entrées dans le récapitulatif";
$lang['scale']['help_add4']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour les modifier";

$lang['scale']['help_list1']="Pour afficher une échelle en détail, cliquez sur le nom de cette échelle";
$lang['scale']['help_list2']="Vous pouvez supprimer une échelle en cliquant sur l'icône de suppression qui lui est associée";
$lang['scale']['help_list3']="Vous pouvez modifier une échelle en cliquant sur l'icône de modification qui lui est associée";
$lang['scale']['help_list4']="Pour ajouter une échelle, cliquez sur le lien 'ajouter une échelle' dans la barre de titre";
$lang['scale']['help_list5']="Vous pouvez faire une recherche d'échelle à tout moment en cliquant sur 'recherche'";

$lang['scale']['help_mod1']="Vous pouvez modifier chacun des paramètres dans le formulaire ci-dessus";
$lang['scale']['help_mod2']="Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif";
$lang['scale']['help_mod3']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour modifier à nouveau les données";

$lang['scale']['help_det1']="Pour afficher l'échelle parente de l'échelle détaillée, cliquez sur le nom de cette échelle";
$lang['scale']['help_det2']="Vous pouvez supprimer cette échelle en cliquant sur l'icône de suppression qui lui est associée";
$lang['scale']['help_det3']="Vous pouvez modifier cette échelle en cliquant sur l'icône de modification qui lui est associée";

$lang['scale']['help_sup1']="Vous devez impérativement choisir une méthode de suppression pour supprimer une échelle";
$lang['scale']['help_sup2']="Pour des raisons de sécurité, vous devez recopier le texte-image dans le champ prévu à cet effet afin de valider la suppression";
$lang['scale']['help_sup3']="Attention la suppression dans le module échelle entraine de nombreux changements dans l'ensemble des modules, cette suppression est reservée aux administrateurs avertis";
?>

==> dl.php?src=linea21_1_3.zip: linea21/languages/fr/lang_scale.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



/*	nommage des modules
*  	*/
$lang['scale']['name']="échelle";
$lang['scale']['confirm_add'] = "Ajout de l'échelle réalisé avec succès\n";
$lang['scale']['confirm_mod'] = "Modification de l'échelle réalisée avec succès\n";
$lang['scale']['confirm_sup'] ="Suppression de l'échelle réalisée avec succès\n";


/*	nommage rubrique module
*  	*/
$lang['scale']['add']= "Ajout d'une ".$lang['scale']['name'];
$lang['scale']['mod']= "Modification d'une ".$lang['scale']['name'];
$lang['scale']['sup']= "Suppression d'une ".$lang['scale']['name'];
$lang['scale']['det']= "Détails de l'".$lang['scale']['name'];
$lang['scale']['list']= "Consultation des échelles";


/*	nommage rubrique add / mod /det
*  	*/
$lang['scale']['add_title']="Saisie des informations de la nouvelle ".$lang['scale']['name'];



/*	nommage rubrique sup
*  	*/
$lang['scale']['sup_massd']= "Supprimer toutes les échelles filles attachées ?";
$lang['scale']['sup_massm']= "Attacher toutes ses échelles filles à une autre échelle ?"; 
$lang['scale']['sup_transfert']= "Echelle de transfert"; 
/*	nommage élément rubrique
*  	*/
$lang['scale']['denomination']="Dénomination de l'".$lang['scale']['name'];
$lang['scale']['surface']="Surface de la zone en";
$lang['scale']['population']="Nombre d'habitants";
$lang['scale']['root']="Echelle parente";
$lang['scale']['comment']="Commentaire lié à cette ".$lang['scale']['name'];


/*	nommage quickbox
*  	*/
$lang['scale']['qb_titleadd']=" derniers ajouts effectués";
$lang['scale']['qb_titlemod']=" dernières modifications effectuées";
$lang['scale']['qb_titlesup']=" dernières suppressions effectuées";


/*	divers
*  	*/
$lang['scale']['select_choice']="~~ Faites votre choix dans la liste ci dessous ~~";


/*	messages
*  	*/
$lang['scale']['object_notdenomination']="Vous devez impérativement entrer une dénomination d'échelle.";
$lang['scale']['object_notnumsurface']="La superficie saisie doit être de type numérique.";
$lang['scale']['object_notnuminhabitants']="La population saisie doit être de type numérique (entier).";
$lang['scale']['object_notroot']="Vous devez impérativement déterminer une échelle <em>parente</em> à la nouvelle échelle.";
$lang['scale']['sup_nomethod']="Vous devez impérativement choisir une méthode de suppression!";
$lang['scale']['sup_noscale']="Vous devez impérativement choisir une échelle de transfert!";
$lang['scale']['sup_scale_info1']="Attention, le transfert de cette échelle induit le transfert des échelles filles attachées, projets, actualités, publications et indicateurs liés à cette échelle!";
$lang['scale']['sup_scale_info2']="Attention, la suppression de cette échelle induit celle des échelles filles attachées, projets, actualités, publications et indicateurs liés à cette échelle!";


/*	rubrique d'aide
*  	*/
$lang['scale']['help_add1']="Pour ajouter une échelle, vous devez entrer chacun de ses paramètres dans le formulaire ci-dessus";
$lang['scale']['help_add2']="Vous devez impérativement ajouter une échelle parente à la nouvelle échelle";
$lang['scale']['help_add3']="Après avoir validé le formulaire d'ajout, vérifiez les informations entrées dans le récapitulatif";
$lang['scale']['help_add4']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour les modifier";

$lang['scale']['help_list1']="Pour afficher une échelle en détail, cliquez sur le nom de cette échelle";
$lang['scale']['help_list2']="Vous pouvez supprimer une échelle en cliquant sur l'icône de suppression qui lui est associée";
$lang['scale']['help_list3']="Vous pouvez modifier une échelle en cliquant sur l'icône de modification qui lui est associée";
$lang['scale']['help_list4']="Pour ajouter une échelle, cliquez sur le lien 'ajouter une échelle' dans la barre de titre";
$lang['scale']['help_list5']="Vous pouvez faire une recherche d'échelle à tout moment en cliquant sur 'recherche'";

$lang['scale']['help_mod1']="Vous pouvez modifier chacun des paramètres dans le formulaire ci-dessus";
$lang['scale']['help_mod2']="Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif";
$lang['scale']['help_mod3']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour modifier à nouveau les données";

$lang['scale']['help_det1']="Pour afficher l'échelle parente de l'échelle détaillée, cliquez sur le nom de cette échelle";
$lang['scale']['help_det2']="Vous pouvez supprimer cette échelle en cliquant sur l'icône de suppression qui lui est associée";
$lang['scale']['help_det3']="Vous pouvez modifier cette échelle en cliquant sur l'icône de modification qui lui est associée";

$lang['scale']['help_sup1']="Vous devez impérativement choisir une méthode de suppression pour supprimer une échelle";
$lang['scale']['help_sup2']="Pour des raisons de sécurité, vous devez recopier le texte-image dans le champ prévu à cet effet afin de valider la suppression";
$lang['scale']['help_sup3']="Attention, la suppression dans le module échelle entraine de nombreux changements dans l'ensemble des modules, cette suppression est reservée aux administrateurs avertis";
?>
